Column

Struct Column 

pub struct Column { /* private fields */ }
A simple interface for building and adding new columns.

You’ll always start from a column name with_name and then decide if you want to build the new column’s value from previous columns or from a specific one using a regex.

Example

use csvsc::prelude::*;

Column::with_name("full name").from_all_previous().definition("{name} {last name}");

Implementations

Source

impl Column

pub fn with_name(name: &str) -> Column

Start your new column with a name

pub fn from_all_previous(self) -> MixColumn

Build the new column’s value from the values of existing columns so far

pub fn from_column(self, name: &str) -> IncompleteRegexColumn

Build the new column’s value from a single column and a regex that you’ll use to extract some values.

This is very useful for adding data contained in the csv file’s name that is contained in the _source column (automatically added).

Example
use csvsc::prelude::*;

Column::with_name("year")
    .from_column("_source")
    .with_regex("report_([0-9]{4}).csv").unwrap()
    .definition("$1");