pub trait GroupCriteria {
// Required method
fn group_for(&self, headers: &Headers, row: &Row) -> u64;
}Expand description
Types implementing this trait can be used to group rows in a row stream,
both for group() and
adjacent_group()
pub trait GroupCriteria {
// Required method
fn group_for(&self, headers: &Headers, row: &Row) -> u64;
}Types implementing this trait can be used to group rows in a row stream,
both for group() and
adjacent_group()