pub struct InputStream { /* private fields */ }Expand description
A structure for creating a transformation chain from input files.
Most of the time you’ll start your processing chain using .from_readers()
or .from_paths() and then chain the methods of the
RowStream trait. However there are more options
for the cases where you need to customize how your input is read.